@@ -288,7 +288,7 @@ class Reactor(IReactor):
         from orionis.console.commands.cache import CacheClearCommand
         from orionis.console.commands.scheduler_work import ScheduleWorkCommand
         from orionis.console.commands.scheduler_list import ScheduleListCommand
-        from orionis.console.commands.make_listener import MakeListenerCommand
+        from orionis.console.commands.make_command import MakeCommand
 
         # List of core command classes to load (extend this list as more core commands are added)
         core_commands = [
@@ -300,7 +300,7 @@ class Reactor(IReactor):
             CacheClearCommand,
             ScheduleWorkCommand,
             ScheduleListCommand,
-            MakeListenerCommand
+            MakeCommand
         ]
 
         # Iterate through the core command classes and register them
