@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from datetime import datetime
 from typing import Optional
 from orionis.console.entities.scheduler_event_data import SchedulerEventData
 
@@ -7,16 +8,17 @@ class SchedulerError(SchedulerEventData):
     """
     Represents an error event triggered by the scheduler.
 
-    This data class extends `SchedulerEventData` and is used to encapsulate
-    information related to errors that occur during scheduler operations.
-    It stores the exception that caused the error and the associated traceback
-    for debugging and logging purposes.
+    This data class extends `SchedulerEventData` and encapsulates information about errors
+    that occur during scheduler operations. It stores the exception that caused the error,
+    the traceback for debugging, and the time the error occurred.
 
     Attributes
     ----------
-    exception : Optional[BaseException]
+    time : str or datetime, optional
+        The time when the error occurred. Can be a string or a datetime object.
+    exception : BaseException, optional
         The exception instance that caused the scheduler error, if any.
-    traceback : Optional[str]
+    traceback : str, optional
         The traceback string providing details about where the error occurred.
 
     Returns
@@ -25,6 +27,9 @@ class SchedulerError(SchedulerEventData):
         An instance containing details about the scheduler error event.
     """
 
+    # The time when the error occurred (string or datetime)
+    time: str | datetime = None
+
     # Exception that caused the scheduler error, if present
     exception: Optional[BaseException] = None
 
