@@ -189,18 +189,52 @@ class ReflectionInstance(IReflectionInstance):
         """
         return self._instance.__class__.__bases__
 
-    def getSourceCode(self) -> Optional[str]:
+    def getSourceCode(self, method: str = None) -> Optional[str]:
         """
-        Get the source code of the instance's class.
+        Retrieve the source code of the instance's class or a specific method.
+
+        Parameters
+        ----------
+        method : str, optional
+            The name of the method whose source code should be retrieved. If not provided,
+            the source code of the entire class is returned.
 
         Returns
         -------
         Optional[str]
-            The source code if available, None otherwise
+            The source code as a string if available; otherwise, None.
+
+        Raises
+        ------
+        None
+            This method does not raise exceptions; it returns None if the source code cannot be retrieved.
+
+        Notes
+        -----
+        - If `method` is specified and refers to a private method, name mangling is handled automatically.
+        - If the source code cannot be found (e.g., for built-in or dynamically generated classes/methods), None is returned.
         """
         try:
-            return inspect.getsource(self._instance.__class__)
+            if not method:
+                # Return the source code of the class
+                return inspect.getsource(self._instance.__class__)
+            else:
+
+                # Handle private method name mangling
+                if method.startswith("__") and not method.endswith("__"):
+                    class_name = self.getClassName()
+                    method = f"_{class_name}{method}"
+
+                # Check if the method exists
+                if not self.hasMethod(method):
+                    return None
+
+                # Return the source code of the specified method
+                return inspect.getsource(getattr(self._instance.__class__, method))
+
         except (TypeError, OSError):
+
+            # Return None if the source code cannot be retrieved
             return None
 
     def getFile(self) -> Optional[str]:
@@ -247,27 +281,39 @@ class ReflectionInstance(IReflectionInstance):
         """
         return name in self.getAttributes()
 
-    def getAttribute(self, name: str) -> Any:
+    def getAttribute(self, name: str, default: Any = None) -> Any:
         """
-        Get an attribute value by name.
+        Retrieve the value of an attribute by its name from the instance.
 
         Parameters
         ----------
         name : str
-            The attribute name
+            The name of the attribute to retrieve.
+        default : Any, optional
+            The value to return if the attribute does not exist (default is None).
 
         Returns
         -------
         Any
-            The attribute value
+            The value of the specified attribute if it exists; otherwise, returns the provided `default` value.
 
         Raises
         ------
         AttributeError
-            If the attribute doesn't exist
+            If the attribute does not exist and no default value is provided.
+
+        Notes
+        -----
+        This method first checks the instance's attributes dictionary for the given name.
+        If not found, it attempts to retrieve the attribute directly from the instance using `getattr`.
+        If the attribute is still not found, the `default` value is returned.
         """
+
+        # Get all attributes of the instance (public, protected, private, dunder)
         attrs = self.getAttributes()
-        return attrs.get(name, None)
+
+        # Try to get the attribute from the attributes dictionary; if not found, use getattr with default
+        return attrs.get(name, getattr(self._instance, name, default))
 
     def setAttribute(self, name: str, value: Any) -> bool:
         """
@@ -328,19 +374,38 @@ class ReflectionInstance(IReflectionInstance):
 
     def getAttributes(self) -> Dict[str, Any]:
         """
-        Get all attributes of the instance, including public, private, protected, and dunder attributes.
+        Retrieve all attributes of the instance, including public, protected, private, and dunder (magic) attributes.
+
+        This method aggregates attributes from all visibility levels by combining the results of
+        `getPublicAttributes`, `getProtectedAttributes`, `getPrivateAttributes`, and `getDunderAttributes`.
+        The result is cached for subsequent calls to improve performance.
 
         Returns
         -------
         Dict[str, Any]
-            Dictionary of all attribute names and their values
+            A dictionary mapping attribute names (as strings) to their corresponding values for all
+            attributes of the instance, including public, protected, private, and dunder attributes.
+
+        Notes
+        -----
+        - The returned dictionary includes all instance attributes, regardless of their visibility.
+        - Private attribute names are unmangled (class name prefix is removed).
+        - The result is cached in the instance to avoid redundant computation on repeated calls.
         """
-        return {
-            **self.getPublicAttributes(),
-            **self.getProtectedAttributes(),
-            **self.getPrivateAttributes(),
-            **self.getDunderAttributes()
-        }
+
+        # Check if the cache for attributes exists; if not, compute and store it
+        if not hasattr(self, "_ReflectionInstance__cacheGetAttributes"):
+
+            # Merge all attribute dictionaries from different visibility levels
+            self.__cacheGetAttributes = {
+                **self.getPublicAttributes(),
+                **self.getProtectedAttributes(),
+                **self.getPrivateAttributes(),
+                **self.getDunderAttributes()
+            }
+
+        # Return the cached dictionary of attributes
+        return self.__cacheGetAttributes
 
     def getPublicAttributes(self) -> Dict[str, Any]:
         """
@@ -532,33 +597,13 @@ class ReflectionInstance(IReflectionInstance):
         if not callable(method):
             raise ReflectionAttributeError(f"Cannot set attribute '{name}' to a non-callable value.")
 
-        # Extarct the signature of the method and classtype
-        sign = inspect.signature(method)
-        classtype = self.getClass()
-
-        # Check first parameter is 'cls'
-        params = list(sign.parameters.values())
-        if not params or params[0].name != "cls":
-            raise ReflectionAttributeError(f"The first (or only) argument of the method must be named 'cls' and must be of type {classtype}.")
-
-        # Get the expected type from the first parameter's annotation
-        annotation = params[0].annotation
-        if annotation != classtype:
-            raise ReflectionAttributeError(
-                f"The first argument has an incorrect annotation. Expected '{classtype}', but got '{annotation}'."
-            )
-
         # Handle private method name mangling
         if name.startswith("__") and not name.endswith("__"):
             class_name = self.getClassName()
             name = f"_{class_name}{name}"
 
-        # Check if the method already exists
-        if hasattr(self._instance, name):
-            raise ReflectionAttributeError(f"Attribute '{name}' already exists on '{self.getClassName()}'.")
-
         # Set the method on the instance
-        setattr(self._instance.__class__, name, method)
+        setattr(self._instance, name, method)
 
         # Return True
         return True
@@ -642,24 +687,44 @@ class ReflectionInstance(IReflectionInstance):
 
     def getMethods(self) -> List[str]:
         """
-        Get all method names of the instance.
+        Retrieve all method names associated with the instance, including public, protected, private,
+        class, and static methods.
+
+        This method aggregates method names from various categories (public, protected, private, class,
+        and static) by calling the corresponding getter methods. The result is cached for subsequent calls
+        to improve performance.
 
         Returns
         -------
         List[str]
-            List of method names
+            A list containing the names of all methods (instance, class, and static) defined on the instance's class,
+            including public, protected, and private methods.
+
+        Notes
+        -----
+        - The returned list includes method names from all visibility levels (public, protected, private),
+          as well as class and static methods.
+        - The result is cached in the instance to avoid redundant computation on repeated calls.
         """
-        return [
-            *self.getPublicMethods(),
-            *self.getProtectedMethods(),
-            *self.getPrivateMethods(),
-            *self.getPublicClassMethods(),
-            *self.getProtectedClassMethods(),
-            *self.getPrivateClassMethods(),
-            *self.getPublicStaticMethods(),
-            *self.getProtectedStaticMethods(),
-            *self.getPrivateStaticMethods(),
-        ]
+
+        # Check if the cache for method names exists; if not, compute and store it
+        if not hasattr(self, "_ReflectionInstance__cacheGetMethods"):
+
+            # Compute and cache the list of method names
+            self.__cacheGetMethods = [
+                *self.getPublicMethods(),
+                *self.getProtectedMethods(),
+                *self.getPrivateMethods(),
+                *self.getPublicClassMethods(),
+                *self.getProtectedClassMethods(),
+                *self.getPrivateClassMethods(),
+                *self.getPublicStaticMethods(),
+                *self.getProtectedStaticMethods(),
+                *self.getPrivateStaticMethods(),
+            ]
+
+        # Return the cached list of method names
+        return self.__cacheGetMethods
 
     def getPublicMethods(self) -> List[str]:
         """
@@ -1042,9 +1107,6 @@ class ReflectionInstance(IReflectionInstance):
             # Check if the attribute is a class method
             if isinstance(attr, classmethod):
 
-                # Get the underlying function
-                func = attr.__func__
-
                 # Check if a private class method
                 if name.startswith(f"_{class_name}"):
                     private_class_methods.append(str(name).replace(f"_{class_name}", ""))
